/* BieMme Italia 
* BminiIO library function for Arduino.
* This library let you leverage the power of the Bmini shield for Arduino.
*
*
* License: CC Attribution-ShareAlike 4.0 International
* http://creativecommons.org/licenses/by-sa/4.0/legalcode
*
* BieMme Italia 2014 - http://www.biemmeitalia.net
* @author Possamai Lino
*/

#include "BminiIO.h"

// function definitions
int analogReadPin(int pin_number);


// Bmini pins initialization
void bmini_init()
{	
	//digital inputs init
	pinMode(DIGIN1, INPUT_PULLUP);
	pinMode(DIGIN2, INPUT_PULLUP);
	pinMode(DIGIN3, INPUT_PULLUP);
	pinMode(DIGIN4, INPUT_PULLUP);

	//digital outputs init
	pinMode(RELAY1, OUTPUT);
	pinMode(RELAY2, OUTPUT);
	pinMode(RELAY3, OUTPUT);
	pinMode(RELAY4, OUTPUT);

	#ifndef ARDUINO_ETHERNET
	//pwm
	pinMode(PWM1, OUTPUT);
	pinMode(PWM2, OUTPUT);
	#endif
	#ifdef ARDUINO_MINI
	//modbus communication led status
	pinMode(MODBUSLED, OUTPUT);
	#endif

	//modbus enable pin
	pinMode(MODBUSPIN, OUTPUT);
	
}

//relays states
void relay(int relay_number, int value){
	int pin_relay;
	switch(relay_number){
		case 1:
			pin_relay = RELAY1;
			break;
		case 2:
			pin_relay = RELAY2;
			break;
		case 3:
			pin_relay = RELAY3;
			break;
		case 4:
			pin_relay = RELAY4;
			break;
		default:
			// no more than 4 relays are allowed
			return;
	}
	digitalWrite(pin_relay,value);
}

#ifndef ARDUINO_ETHERNET
//values allowed range [0,255]
void pwm(int pwm_number, int value){				
	int pwm_pin;
	switch(pwm_number){
		case 1:
			pwm_pin = PWM1; 
			break;
		case 2:
			pwm_pin = PWM2;
			break;
		default:
			// no more than 2 pwm are allowed
			return;
        }
	if (value >= 0 && value <= 255){
		analogWrite(pwm_pin, value);
	}
}
#endif

//Get digital inputs status
int get_inputs(int di_number){
	int dig_pin, ret;

	switch(di_number){
		case 1:
			dig_pin = DIGIN1;
			break;
		case 2:
			dig_pin = DIGIN2;
			break;
		case 3:
			dig_pin = DIGIN3;
			break;
		case 4:
			dig_pin = DIGIN4;
			break;
		default:
			return -1;
	}
	ret = 1-digitalRead(dig_pin);
	return ret;
}

float readTemperatureC(int an_number){

	int reading = analogReadPin(an_number);
	
	if (reading > -999){

		float voltage = reading * 5.0;
		voltage /= 1024.0; 
	 
		 //converting from 10 mv per degree wit 500 mV offset
		//to degrees ((volatge - 500mV) times 100)
	 	float temperatureC = (voltage - 0.5) * 100 ; 
	 
		return temperatureC;
 	}else{
		return -999;
	}


}

// Reads the temperature from a TMP36 like sensor
float readTemperatureF(int an_number){

	int reading = analogReadPin(an_number);

	if (reading > -999){
		float voltage = reading * 5.0;
		voltage /= 1024.0; 
	 
		 //converting from 10 mv per degree wit 500 mV offset
		//to degrees ((volatge - 500mV) times 100)
	 	float temperatureC = (voltage - 0.5) * 100 ; 

	 	// now convert to Fahrenheight
		float temperatureF = (temperatureC * 9.0 / 5.0) + 32.0;
		return temperatureF;
	}else{
		return -999;
	}
}


//Reads analog pins
int analogReadPin(int pin_number){
        int pin_toread;
        switch(pin_number){
                case 1:
                        pin_toread = ANALOG1;
                        break;
                case 2:
                        pin_toread = ANALOG2;
                        break;
                case 3:
                        pin_toread = ANALOG3;
                        break;
                case 4:
                        pin_toread = ANALOG4;
                        break;
		#ifdef ARDUINO_MINI
		case 5:
                        pin_toread = ANALOG5;
			break;
		case 6:
			pin_toread = ANALOG6;
			break;
		case 7:
			pin_toread = ANALOG7;
			break;
		case 8:
			pin_toread = ANALOG8;
			break;
		#endif
                default:
                        // no more than 4 analog inputs are allowed for the Arduino Ethernet and UNO board
                        return -999;
        }
        int value = analogRead(pin_toread);

        return value;

}

